Spectroscopic Pipeline
======================

:code:`tshirt` has a pipeline for spectroscopic data that can:

- Do background subtraction of the images
- Find the 2D profile of images
- Extract the spectrum for all images
- Gather together a dynamic spectrum
- Plot and save wavelength-binned data


.. toctree::
   :maxdepth: 2
   :caption: Contents:
   
   self
   test_spec_pipeline.ipynb
   CoRoT-1b_Example_Annotated_Notebook.ipynb
   batch_processing
   parameter_file
   

